/*****************************************************************************

This source code is made available to you under the terms of the Open
Development License.  This Package should be accompanied by a file that
contains the associated licensing terms.  If you are unable to find this file,
please refer to its location on the Internet at www.rocklyte.com/license.html.

******************************************************************************

###CLASS###
Name:      FieldMonitor
Version:   1.1
Status:    Stable
ID:        ID_FIELDMONITOR
Date:      June 2003
Category:  System
Author:    Rocklyte Systems
Copyright: Rocklyte Systems (c) 2003.  All rights reserved.
Short:     The FieldMonitor class is used to watch objects for field changes.
Keywords:  field, object, monitor, watch

###DESCRIPTION###


###END###

*****************************************************************************/

#include <pandora/system/all.h>
#include <pandora/modules/strings.h>

static ERROR CMDInit(OBJECTPTR, struct KernelBase *);
static ERROR CMDExpunge(void);

#define VER_FIELDMONITOR 1.1

EXPORT struct ModHeader ModHeader = {
   MODULE_HEADER_V1, CMDInit, NULL, NULL, CMDExpunge,
   JMP_DEFAULT, 0, CPU_PC, VER_FIELDMONITOR, VER_KERNEL,
   "Rocklyte Systems",
   "Rocklyte Systems (c) 2003.  All rights reserved.",
   "June 2003",
   "FieldMonitor"
};

static struct KernelBase  *KernelBase = 0;
static struct StringsBase *StringsBase = 0;
static OBJECTPTR modStrings = 0;
static OBJECTPTR FieldMonitorClass = 0;

/*****************************************************************************
** Class definition.
*/

struct FieldMonitor {
   OBJECT_HEADER        /* Class header */
   OBJECTID ObjectID;

   PRIVATE_FIELDS
   FIELD    FieldID;
   UBYTE    Field[40];
};

static ERROR GET_Field(struct FieldMonitor *, STRING *);

static ERROR SET_Field(struct FieldMonitor *, STRING);

static struct FieldArray FieldMonitorFields[] = {
   { "Object",  0, FDF_OBJECTID|FDF_RW,  0, NULL, NULL },
   /*** Virtual fields ***/
   { "Field",   0, FDF_STRING|FDF_RW,    0, GET_Field, SET_Field },
   END_FIELD
};

static ERROR MONITOR_ActionNotify(struct FieldMonitor *, struct acActionNotify *);
static ERROR MONITOR_Activate(struct FieldMonitor *, APTR);
static ERROR MONITOR_FieldNotify(struct FieldMonitor *, struct acFieldNotify *);
static ERROR MONITOR_Free(struct FieldMonitor *, APTR);
static ERROR MONITOR_Init(struct FieldMonitor *, APTR);

static struct ActionArray FieldMonitorActions[] = {
   { AC_ActionNotify,     MONITOR_ActionNotify },
   { AC_Activate,         MONITOR_Activate },
   { AC_FieldNotify,      MONITOR_FieldNotify },
   { AC_Free,             MONITOR_Free },
   { AC_Init,             MONITOR_Init },
   { NULL, NULL }
};

/*****************************************************************************
** Command: Init()
*/

static ERROR CMDInit(OBJECTPTR argModule, struct KernelBase *argKernelBase)
{
   KernelBase = argKernelBase;

   if (CreateObject(ID_MODULE, NULL, &modStrings, NULL, 
      FID_Name|TSTRING,   "strings", 
      FID_Version|TFLOAT, MODVERSION_STRINGS,
      TAGEND) IS ERR_Okay) {
      if (GetField(modStrings, FID_ModBase, FT_POINTER, &StringsBase) != ERR_Okay) {
         return(ObjectError(argModule, ERH_InitModule, ERR_GetField));
      }
   }
   else return(ObjectError(argModule, ERH_InitModule, ERR_CreateObject));

   return(CreateObject(ID_CLASS, NULL, (OBJECTPTR *)&FieldMonitorClass, NULL,
      FID_BaseClassID|TLONG, ID_FIELDMONITOR,
      FID_Version|TFLOAT,    VER_FIELDMONITOR,
      FID_Name|TSTRING,      "FieldMonitor",
      FID_Category|TLONG,    CCF_SYSTEM,
      FID_Actions|TPTR,      FieldMonitorActions,
      FID_Fields|TPTR,       FieldMonitorFields,
      FID_Size|TLONG,        sizeof(struct FieldMonitor),
      TAGEND));
}

/*****************************************************************************
** Command: Expunge()
*/

static ERROR CMDExpunge(void)
{
   if (modStrings)        { acFree(modStrings);  modStrings  = NULL; }
   if (FieldMonitorClass) { acFree(FieldMonitorClass); FieldMonitorClass = NULL; }
   return(ERR_Okay);
}

/*****************************************************************************
** FieldMonitor: ActionNotify
*/

static ERROR MONITOR_ActionNotify(struct FieldMonitor *Self, struct acActionNotify *Args)
{
   if (Args->ActionID IS AC_SetUnlistedField) {
      struct acSetUnlistedField *set;

      set = (struct acSetUnlistedField *)Args->Args;
      if (StrCompare(Self->Field, set->Field, 0, STR_MATCHLENGTH) IS ERR_Okay) {
         Action(AC_Activate, Self, NULL);
      }
   }
   return(ERR_Okay);
}

/*****************************************************************************
** FieldMonitor: Activate
*/

static ERROR MONITOR_Activate(struct FieldMonitor *Self, APTR Void)
{
   LONG i, count;

   if ((count = TotalChildren(Self->Head.UniqueID)) > 0) {
      struct ChildEntry list[count];
      if (ListChildren(GetUniqueID(Self), list, &count) IS ERR_Okay) {
         for (i=0; i < count; i++) {
            ActionMsg(AC_Activate, list[i].ObjectID, NULL);
         }
      }
   }
   else DPrintF("Activate:","[FieldMonitor:%d] I have no child objects that need to be activated.", Self->Head.UniqueID);

   return(ERR_Okay);
}

/*****************************************************************************
** FieldMonitor: FieldNotify
*/

static ERROR MONITOR_FieldNotify(struct FieldMonitor *Self, struct acFieldNotify *Args)
{
   Action(AC_Activate, Self, NULL);
   return(ERR_Okay);
}

/*****************************************************************************
** FieldMonitor: Free
*/

static ERROR MONITOR_Free(struct FieldMonitor *Self, APTR Void)
{
   OBJECTPTR object;

   if (Self->ObjectID) {
      if (AccessObject(Self->ObjectID, 5000, &object) IS ERR_Okay) {
         UnsubscribeField(object, Self->FieldID, Self->Head.UniqueID);
         UnsubscribeAction(object, AC_SetUnlistedField, Self->Head.UniqueID);
         ReleaseObject(object);
      }
   }

   return(ERR_Okay);
}

/*****************************************************************************
** FieldMonitor: Init
*/

static ERROR MONITOR_Init(struct FieldMonitor *Self, APTR Void)
{
   OBJECTPTR monitor;

   if ((!Self->ObjectID) OR (!Self->FieldID)) {
      return(ObjectError(Self, ERH_Init, ERR_FieldNotSet));
   }

   if (AccessObject(Self->ObjectID, 5000, &monitor) IS ERR_Okay) {
      SubscribeField(monitor, Self->FieldID, Self);
      SubscribeAction(monitor, AC_SetUnlistedField, Self);
      ReleaseObject(monitor);
   }

   return(ERR_Okay);
}

/*****************************************************************************

###FIELD###
Name:   Field
Short:  Specifies the field that you would like to monitor.
Type:   STRING
Status: Read/Write

###DESCRIPTION###


###SEE ALSO###
Field: Object

###END###

*****************************************************************************/

static ERROR GET_Field(struct FieldMonitor *Self, STRING *Value)
{
   *Value = Self->Field;
   return(ERR_Okay);
}

static ERROR SET_Field(struct FieldMonitor *Self, STRING Value)
{
   WORD i;

   if ((!Value) OR (!*Value)) {
      Self->Field[0] = 0;
      return(ERR_Okay);
   }

   for (i=0; (Value[i]) AND (i < sizeof(Self->Field)-1); i++) Self->Field[i] = Value[i];
   Self->Field[i] = 0;

   ResolveFields(Self->Field, &Self->FieldID, TAGEND);

   return(ERR_Search);
}

/*****************************************************************************

###FIELD###
Name:   Object
Short:  The object that you want to monitor.
Type:   OBJECTID
Status: Read/Write

###DESCRIPTION###
<p>The object that is to receive the action call must be specified in this
field.  You are required to set this field unless you intend to use action
monitoring, in which case you should set the Monitor field.</p>

<p>If you set this field with a string, the object reference will be
translated to an ID in run-time.</p>

###SEE ALSO###
Fields: Field

###END###

*****************************************************************************/
