#ifndef SYSTEM_ERRORS_H
#define SYSTEM_ERRORS_H TRUE

/*
**   errors.h
**
**   Error code listing.
**
**   (C) Copyright 1996-2004 Rocklyte Systems.
**       All Rights Reserved.
*/

/*****************************************************************************
** Universal error codes returned by most functions.
*/

#define ERR_True                   0
#define ERR_Okay                   0
#define ERR_NoMemory               1
#define ERR_NoPointer              2
#define ERR_InUse                  3
#define ERR_Failed                 4
#define ERR_File                   5
#define ERR_BadData                6
#define ERR_Search                 7
#define ERR_InitModule             8
#define ERR_FileMissing            9
#define ERR_WrongVersion           10
#define ERR_Args                   11
#define ERR_NoData                 12
#define ERR_Read                   13
#define ERR_Write                  14
#define ERR_LockFailed             15
#define ERR_ExamineFailed          16
#define ERR_LostClass              17
#define ERR_NoAction               18
#define ERR_NoSupport              19
#define ERR_Memory                 20
#define ERR_TimeOut                21
#define ERR_NoStats                22
#define ERR_LowCapacity            23
#define ERR_Init                   24
#define ERR_NoPermission           25
#define ERR_SystemCorrupt          26
#define ERR_NeedOwner              27
#define ERR_OwnerNeedsBitmap       28
#define ERR_KernelVersion          29
#define ERR_NeedWidthHeight        30
#define ERR_NegativeSubClassID     31
#define ERR_NegativeClassID        32
#define ERR_MissingClassName       33
#define ERR_OutOfRange             34
#define ERR_ObtainMethod           35
#define ERR_ArrayFull              36
#define ERR_Query                  37
#define ERR_LostOwner              38
#define ERR_DoNotExpunge           39
#define ERR_MemoryCorrupt          40
#define ERR_FieldSearch            41
#define ERR_InvalidPath            42
#define ERR_SetField               43
#define ERR_MarkedForDeletion      44
#define ERR_IllegalMethodID        45
#define ERR_IllegalActionID        46
#define ERR_ModuleOpenFailed       47
#define ERR_IllegalActionAttempt   48
#define ERR_EntryMissingHeader     49
#define ERR_ModuleMissingInit      50
#define ERR_ModuleInitFailed       51
#define ERR_MemoryDoesNotExist     52
#define ERR_DeadLock               53
#define ERR_SystemLockedUp         54
#define ERR_ModuleMissingName      55
#define ERR_AddClass               56
#define ERR_Activate               57
#define ERR_ActionFailed           58
#define ERR_DoubleInit             59
#define ERR_FieldNotSet            60
#define ERR_MissingClass           61
#define ERR_FileReadFlag           62
#define ERR_FileWriteFlag          63
#define ERR_Draw                   64
#define ERR_NoMethods              65
#define ERR_NoMatchingObject       66
#define ERR_AccessMemory           67
#define ERR_MissingLocation        68
#define ERR_NoExclusiveLock        69
#define ERR_NoSearchResult         70
#define ERR_StatementUnsatisfied   71
#define ERR_ObjectCorrupt          72
#define ERR_OwnerPassThrough       73
#define ERR_UnsupportedOwner       74
#define ERR_False                  75
#define ERR_ExclusiveDenied        76
#define ERR_AllocMemory            77
#define ERR_NewObject              78
#define ERR_GetField               79
#define ERR_NoFieldAccess          80
#define ERR_ReservedAssign         81
#define ERR_InvalidDimension       82
#define ERR_FieldTypeMismatch      83
#define ERR_UnrecognisedFieldType  84
#define ERR_BufferOverflow         85
#define ERR_DirectoryEmpty         86
#define ERR_UnsupportedField       87
#define ERR_Mismatch               88
#define ERR_OutOfBounds            89
#define ERR_Seek                   90
#define ERR_ReallocMemory          91
#define ERR_Loop                   92
#define ERR_FileExists             93
#define ERR_ResolveAssign          94
#define ERR_CreateObject           95
#define ERR_MemoryInfo             96
#define ERR_ResolveFields          97
#define ERR_NotInitialised         98
#define ERR_ResourceExists         99
#define ERR_Refresh                100
#define ERR_ListChildren           101
#define ERR_SystemCall             102
#define ERR_SmallMask              103
#define ERR_LimitedSuccess         104
#define ERR_Cancelled              105
#define ERR_EmptyString            106
#define ERR_Terminate              107
#define ERR_ObjectExists           108
#define ERR_Forbid                 109
#define ERR_Resize                 110
#define ERR_Redimension            111
#define ERR_AllocSemaphore         112
#define ERR_AccessSemaphore        113
#define ERR_NothingDone            114
#define ERR_CreateFile             115
#define ERR_DeleteFile             116 /* Deletion of dir/file failed (e.g. permissions, read-only media) */
#define ERR_OpenFile               117 /* File exists but could not be opened */
#define ERR_ReadOnly               118 /* Delete/Write operation failed due to read-only status */
#define ERR_DoesNotExist           119 /* Resource does not exist */
#define ERR_IdenticalPaths         120 /* The destination path is the same as the source path */
#define ERR_Exists                 121 /* Non-specific 'something exists' error */
#define ERR_SanityFailure          122 /* A sanity check failed */
#define ERR_OutOfSpace             123 /* Run out of space, no room to complete request */
#define ERR_END                    124

/* Special flags */

#define ERF_Notified 0x40000000

/* Synonyms */

#define ERR_AccessObject       ERR_ExclusiveDenied
#define ERR_MemoryAccess       ERR_AccessMemory
#define ERR_ObjectDoesNotExist ERR_NoMatchingObject
#define ERR_ObjectMissing      ERR_NoMatchingObject
#define ERR_FileNotFound       ERR_FileMissing
#define ERR_VirtualAssign      ERR_ReservedAssign
#define ERR_Permissions        ERR_NoPermission

/*****************************************************************************
** Error headers.
*/

#define ERH_AccessMemory       1
#define ERH_Action             2
#define ERH_ActionMsg          3
#define ERH_AddMemEntry        4
#define ERH_ActionNotify       5
#define ERH_Activate           6
#define ERH_AddClass           7
#define ERH_AddPrivateObject   8
#define ERH_AddSharedObject    9
#define ERH_AllocMemory        10
#define ERH_Assign             11
#define ERH_AccessObject       12
#define ERH_Bitmap             13
#define ERH_Broadcast          14
#define ERH_Broadcaster        15
#define ERH_CheckAction        16
#define ERH_CheckInit          17
#define ERH_CheckObjectExists  18
#define ERH_Class              19
#define ERH_Clear              20
#define ERH_CloneMemory        21
#define ERH_CloseChannel       22
#define ERH_CloseModule        23
#define ERH_ClosingTag         24
#define ERH_Config             25
#define ERH_CopyArguments      26
#define ERH_CopyData           27
#define ERH_DataChannel        28
#define ERH_Deactivate         29
#define ERH_DeleteAssign       30
#define ERH_Draw               31
#define ERH_Error              32
#define ERH_Event              33
#define ERH_ExpungeModule      34
#define ERH_File               35
#define ERH_FileSystem         36
#define ERH_FindChildren       37
#define ERH_FindClass          38
#define ERH_ResolveClassName   39
#define ERH_FindField          40
#define ERH_FindObject         41
#define ERH_Flush              42
#define ERH_Focus              43
#define ERH_Free               44
#define ERH_FreeClass          45
#define ERH_ReleaseObject      46
#define ERH_FreeMemory         47
#define ERH_FreeMemoryID       48
#define ERH_FreeResource       49
#define ERH_GetClassID         50
#define ERH_GetField           51
#define ERH_GetName            52
#define ERH_Hide               53
#define ERH_Init               54
#define ERH_InitModule         55
#define ERH_Kernel             56
#define ERH_ListChildren       57
#define ERH_ListClassActions   58
#define ERH_ListClassMethods   59
#define ERH_IdentifyFile       60
#define ERH_LoadFromObject     61
#define ERH_ManageAction       62
#define ERH_MemoryIDInfo       63
#define ERH_Method             64
#define ERH_ModEntry           65
#define ERH_Module             66
#define ERH_Move               67
#define ERH_MoveToFront        68
#define ERH_MoveToBack         69
#define ERH_NewClass           70
#define ERH_NewObject          71
#define ERH_NotifySubscribers  72
#define ERH_ObtainMethod       73
#define ERH_SubscribeChannel   74
#define ERH_OpenModule         75
#define ERH_Pandora            76
#define ERH_Pointer            77
#define ERH_ProcessMessages    78
#define ERH_Query              79
#define ERH_Read               80
#define ERH_AllocateClassID    81
#define ERH_UnsubscribeField   82
#define ERH_ReadConfig         83
#define ERH_Realloc            84
#define ERH_GetMessage         85
#define ERH_ReleaseMemory      86
#define ERH_RemoveObject       87
#define ERH_Rename             88
#define ERH_Reset              89
#define ERH_Resize             90
#define ERH_ResolveAssign      91
#define ERH_ReturnArguments    92
#define ERH_SaveImage          93
#define ERH_SaveToObject       94
#define ERH_Screen             95
#define ERH_Script             96
#define ERH_Scroll             97
#define ERH_Seek               98
#define ERH_SetOwner           99
#define ERH_SetField           100
#define ERH_SetUnlistedField   101
#define ERH_SendMessage        102
#define ERH_Show               103
#define ERH_SetName            104
#define ERH_Strings            105
#define ERH_StrReplace         106
#define ERH_StrSearch          107
#define ERH_SubscribeAction    108
#define ERH_SubscribeField     109
#define ERH_SubscribeTimer     110
#define ERH_Subscriber         111
#define ERH_TotalChildren      112
#define ERH_UserClick          113
#define ERH_UserMovement       114
#define ERH_Unhook             115
#define ERH_UnsubscribeAction  116
#define ERH_WatchPublicMemory  117
#define ERH_Write              118
#define ERH_NewChild           119
#define ERH_CopyLocation       120
#define ERH_SubscribeEvent     121
#define ERH_UnsubscribeEvent   122
#define ERH_Function           123
#define ERH_FastFindObject     124
#define ERH_AlterMemory        125
#define ERH_Clipboard          126
#define ERH_Refresh            127
#define ERH_XML                128
#define ERH_ConvertFontCoords  129
#define ERH_CalcStringWidth    130
#define ERH_CreateObject       131
#define ERH_CheckMemoryExists  132
#define ERH_ResolveFields      133
#define ERH_SleepingTask       134
#define ERH_WatchMemory        135
#define ERH_SetContext         136
#define ERH_UnsubscribeChannel 137
#define ERH_UnsubscribeTimer   138
#define ERH_AllocateID         139
#define ERH_GetOwnerID         140
#define ERH_RemoveSharedObject 141
#define ERH_ActionTags         142
#define ERH_RecopyArguments    143
#define ERH_GetFields          144
#define ERH_SetFields          145
#define ERH_GetFieldVariable   146
#define ERH_SetFieldVariable   147
#define ERH_ResolveFieldID     148
#define ERH_ObjectError        149
#define ERH_SendError          150
#define ERH_ListMemory         151
#define ERH_ReallocMemory      152
#define ERH_MemoryPtrInfo      153
#define ERH_Redimension        154
#define ERH_ScanMessages       155
#define ERH_Forbid             156
#define ERH_Permit             157
#define ERH_MessageHook        158
#define ERH_Timer              159
#define ERH_AccessSemaphore    160
#define ERH_ReleaseSemaphore   161
#define ERH_AllocSemaphore     162
#define ERH_FreeSemaphore      163
#define ERH_SetDimension       164
#define ERH_GetDimension       165
#define ERH_GetUnlistedField   166
#define ERH_MoveToPoint        167
#define ERH_ScrollToPoint      168
#define ERH_SetWidth           169
#define ERH_SetHeight          170
#define ERH_SetX               171
#define ERH_SetY               172
#define ERH_SetXOffset         173
#define ERH_SetYOffset         174
#define ERH_GetWidth           175
#define ERH_GetHeight          176
#define ERH_GetX               177
#define ERH_GetY               178
#define ERH_GetXOffset         179
#define ERH_GetYOffset         180
#define ERH_ListTasks          181
#define ERH_LostFocus          182
#define ERH_UpdateMessage      183
#define ERH_ValidateProcess    184
#define ERH_FieldNotify        185
#define ERH_UserClickRelease   186
#define ERH_ListObjects        187
#define ERH_FindPrivateObject  188
#define ERH_RegisterFD         189
#define ERH_AccessSurface      190
#define ERH_ReleaseSurface     191
#define ERH_LockBitmap         192
#define ERH_UnlockBitmap       193
#define ERH_BlitDrawable       194
#define ERH_GetRenderInfo      195
#define ERH_SetRegion          196
#define ERH_Sort               197
#define ERH_END                198

#endif /* SYSTEM_ERRORS_H */
